sosia: Automatic author matching in Scopus on-line
==================================================

sosia is a Python library match authors in the Scopus database, using the `pybliometrics package <https://pybliometrics.readthedocs.io/en/latest/index.html>`_.

.. include:: installation.rst


=======
Example
=======

.. include:: ../README.rst
  :start-after: inclusion-marker-start
  :end-before: inclusion-marker-end


Full reference:

.. currentmodule:: sosia

.. autosummary::

    Original


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. Hidden links for Navigation side panel
.. toctree::
   :maxdepth: 2
   :hidden:

   functioning
   reference
   changelog
   authors
   contributing
